==> modx-2.2.1-pl-ja.zip: modx-2.2.1-pl-ja/core/lexicon/en/user.inc.php <==
<?php
/**
 * User English lexicon topic
 *
 * @language en
 * @package modx
 * @subpackage lexicon
 */
$_lang['active'] = 'Active';
$_lang['address'] = 'Address';
$_lang['administrator'] = 'Administrator';
$_lang['authority'] = 'Authority';
$_lang['change_password'] = 'Change Password';
$_lang['change_password_confirm'] = 'Confirm password';
$_lang['change_password_new'] = 'New password';
$_lang['city'] = 'City';
$_lang['extended_fields'] = 'Extended Fields';
$_lang['extended_fields_msg'] = 'Edit any extended fields that are implemented here.';
$_lang['login_options'] = 'Login Options';
$_lang['minimum_role'] = 'Minimum Role';
$_lang['password'] = 'Password';
$_lang['password_confirm'] = 'Confirm Password';
$_lang['password_gen_gen'] = 'Let MODX generate a password.';
$_lang['password_gen_method'] = 'New password method';
$_lang['password_gen_specify'] = 'Let me specify the password:';
$_lang['password_method'] = 'Password notification method';
$_lang['password_method_email'] = 'Send the new password by e-mail.';
$_lang['password_method_screen'] = 'Show the new password on screen.';
$_lang['password_new'] = 'New Password';
$_lang['password_notification'] = 'Password Notification';
$_lang['password_old'] = 'Old Password';
$_lang['primary_group'] = 'Primary Group';
$_lang['profile_recent_resources'] = 'Recent Resources';
$_lang['profile_recent_resources_desc'] = 'This is a list of your most recently edited Resources.';
$_lang['remote_data'] = 'Remote Data';
$_lang['role'] = 'Role';
$_lang['role_create'] = 'Create Role';
$_lang['role_desc_authority'] = 'The Authority level of the role. Lower Authority levels are stronger, and inherit the Permissions of Roles with higher authorities in the groups they are assigned to.';
$_lang['role_desc_name'] = 'A name for the Role, such as Content Editor, Publisher, System Administrator, etc.';
$_lang['role_desc_description'] = 'A short description of the Role.';
$_lang['role_err_ae'] = 'A role already exists with that name.';
$_lang['role_err_duplicate'] = 'An error occurred while duplicating the role.';
$_lang['role_err_has_users'] = 'There are users with this role. It cannot be deleted.';
$_lang['role_err_nf'] = 'Role not found.';
$_lang['role_err_nfs'] = 'Role not found with id: [[+role]]';
$_lang['role_err_ns'] = 'Role not specified!';
$_lang['role_err_ns_name'] = 'Please specify a name for the role.';
$_lang['role_err_remove'] = 'An error occurred while trying to remove the role.';
$_lang['role_err_remove_admin'] = 'The role you are trying to delete is the admin role. This role cannot be deleted!';
$_lang['role_remove'] = 'Delete Role';
$_lang['role_remove_confirm'] = 'Are you sure you want to delete this role?';
$_lang['roles'] = 'Roles';
$_lang['rrg_drag'] = 'Drag resources into resource groups here.';
$_lang['ugc_mutate'] = 'User Group Access to Context';
$_lang['ugc_grid_title'] = 'User Group Access to Contexts';
$_lang['ugc_remove'] = 'Remove User Group Access to this Context';
$_lang['ugrg_grid_title'] = 'User Group Access to Resource Groups';
$_lang['ugrg_mutate'] = 'User Group Access to Resource Group';
$_lang['ugrg_remove'] = 'Remove User Group Access to this Resource Group';
$_lang['user'] = 'User';
$_lang['user_active_desc'] = 'Whether or not this User is active. If a User is not active, they will not be able to login to any Context or the manager.';
$_lang['user_add_group'] = 'Add User Group to User';
$_lang['user_already_in_use'] = 'User name is already in use!';
$_lang['user_block'] = 'Blocked';
$_lang['user_block_desc'] = 'If checked, this user will be permanently blocked from logging in.';
$_lang['user_blockedafter'] = 'Blocked After';
$_lang['user_blockedafter_desc'] = 'If set, the user will be blocked after this time occurs.';
$_lang['user_blockeduntil'] = 'Blocked Until';
$_lang['user_blockeduntil_desc'] = 'If set, the user will be blocked until this time.';
$_lang['user_changeddata'] = 'Your data has been changed. Please log in again.';
$_lang['user_class_key_desc'] = 'The MODX Class Key for this user. Do not change this unless you know what you are doing.';
$_lang['user_created_password_message'] = 'The User has been created. The password is: [[+password]]';
$_lang['user_confirm_remove'] = 'Are you sure you want to permanently remove this user?';
$_lang['user_country'] = 'Country';
$_lang['user_dob'] = 'Date of birth';
$_lang['user_doesnt_exist'] = 'User does not exist';
$_lang['user_edit_self_msg'] = 'You may need to log out and log in again after saving to fully update your information.</strong><br>Also, should you choose to generate a new password for yourself, it will be sent to you through e-mail.';
$_lang['user_email'] = 'E-mail address';
$_lang['user_err_access_permissions_save'] = 'An error occurred while saving user access permissions.';
$_lang['user_err_ae_group'] = 'User is already in that group!';
$_lang['user_err_already_exists'] = 'User name is already in use!';
$_lang['user_err_already_exists_email'] = 'Email already in use!';
$_lang['user_err_cannot_delete_last_admin'] = 'You cannot remove the last User in the Administrator group, as this will prevent administration of your site.';
$_lang['user_err_cannot_delete_self'] = 'You cannot delete yourself!';
$_lang['user_err_nf'] = 'User not found.';
$_lang['user_err_not_specified'] = 'No user specified!';
$_lang['user_err_not_specified_blockedafter'] = 'Please state the blocked after date in mm/dd/yyyy format. ';
$_lang['user_err_not_specified_blockeduntil'] = 'Please state the blocked until date in mm/dd/yyyy format. ';
$_lang['user_err_not_specified_dob'] = 'Please state the birthdate in mm/dd/yyyy format. ';
$_lang['user_err_not_specified_email'] = 'Please specify a valid email address.';
$_lang['user_err_not_specified_fileman_path'] = 'The directory you have specified either:<br />1) Does not exist.<br />2) Does not have read permissions.<br />3) Is not a directory.';
$_lang['user_err_not_specified_manageraccess'] = 'Please specify whether or not the user should have manager access.';
$_lang['user_err_not_specified_managerstartup'] = 'Please specify an existent, valid document ID for the manager login startup page.';
$_lang['user_err_not_specified_managertheme'] = 'The manager theme you have specified has not been uploaded.';
$_lang['user_err_not_specified_mobnumber'] = 'Please specify a valid mobile phone number. (If in US, please specify area code)';
$_lang['user_err_not_specified_notification_method'] = 'Please specify a notifcation method for the new password.';
$_lang['user_err_not_specified_password'] = 'Please specify a password.';
$_lang['user_err_not_specified_phonenumber'] = 'Please specify a valid phone number. (If in US, please specify area code)';
$_lang['user_err_not_specified_resourcedir'] = 'The directory you\'ve specified is not a valid directory.';
$_lang['user_err_not_specified_resource_baseurl'] = 'Please specify a valid resource URL.';
$_lang['user_err_not_specified_uploadsize'] = 'Please specify a valid max upload size in bytes.';
$_lang['user_err_not_specified_username'] = 'Please specify a user name.';
$_lang['user_err_ns'] = 'User not specified.';
$_lang['user_err_password'] = 'Incorrect password.';
$_lang['user_err_password_invalid'] = 'Invalid password specified.';
$_lang['user_err_password_invalid_old'] = 'Invalid old password.';
$_lang['user_err_password_too_short'] = 'Password is too short!';
$_lang['user_err_password_no_match'] = 'Passwords do not match.';
$_lang['user_err_remove'] = 'An error occurred while trying to remove the user.';
$_lang['user_err_resource_subdirectory'] = 'The directory you\'ve specified does not contain the %s directories.';
$_lang['user_err_save'] = 'An error occurred while saving the user.';
$_lang['user_err_username_invalid'] = 'Invalid username specified.';
$_lang['user_failedlogincount'] = 'Failed Logins';
$_lang['user_failedlogincount_desc'] = 'The number of times this user has failed to login by entering an incorrect password.';
$_lang['user_fax'] = 'Fax';
$_lang['user_female'] = 'Female';
$_lang['user_full_name'] = 'Full name';
$_lang['user_group'] = 'User Group';
$_lang['user_group_create'] = 'Create User Group';
$_lang['user_group_id'] = 'UG ID';
$_lang['user_group_desc_name'] = 'The name of the User Group';
$_lang['user_group_desc_description'] = 'A short description of the User Group';
$_lang['user_group_desc_parent'] = 'The parent group of this group. Used for organizational purposes.';
$_lang['user_group_desc_dashboard'] = 'The Dashboard that members of this Group (who have this Group as their Primary Group) will use.';
$_lang['user_group_document_group_err_already_exists'] = 'The user group is already attached to that document group.';
$_lang['user_group_document_group_err_create'] = 'An error occurred while trying to attach the user group to the document group.';
$_lang['user_group_document_group_err_not_found'] = 'That user group is not attached to that document group!';
$_lang['user_group_document_group_err_remove'] = 'An error occurred while trying to deattach the user group from the document group.';
$_lang['user_group_err_already_exists'] = 'There is already a user group with that name.';
$_lang['user_group_err_create'] = 'An error occurred while trying to create the user group.';
$_lang['user_group_err_nf'] = 'User group not found!';
$_lang['user_group_err_not_found'] = 'User group not found!';
$_lang['user_group_err_not_specified'] = 'No user group specified!';
$_lang['user_group_err_ns'] = 'User group not specified!';
$_lang['user_group_err_ns_name'] = 'Please specify a name for this user group.';
$_lang['user_group_err_remove'] = 'An error occurred while trying to remove the user group.';
$_lang['user_group_err_remove_admin'] = 'You cannot remove the Administrator group.';
$_lang['user_group_err_save'] = 'An error occurred while trying to save the user group.';
$_lang['user_group_management_msg'] = 'Manage user memberships in groups and apply roles.';
$_lang['user_group_member_err_already_in'] = 'User is already in this user group!';
$_lang['user_group_member_err_create'] = 'An error occurred while attempting to add the user to a user group.';
$_lang['user_group_member_err_nf'] = 'User is not in this user group!';
$_lang['user_group_member_err_remove'] = 'An error occurred while trying to remove the user from the group.';
$_lang['user_group_member_err_save'] = 'An error occurred while trying to add the user to the group.';
$_lang['user_group_new'] = 'New User Group';
$_lang['user_group_parent'] = 'Parent Group';
$_lang['user_group_remove'] = 'Delete User Group';
$_lang['user_group_remove_confirm'] = 'Are you sure you want to delete this User Group?';
$_lang['user_group_untitled'] = 'Untitled User Group';
$_lang['user_group_update'] = 'Update User Group';
$_lang['user_group_user_add'] = 'Add User to Group';
$_lang['user_group_user_add_user_desc'] = 'The username of the User to add to the User Group';
$_lang['user_group_user_add_role_desc'] = 'The Role that the User should have in the Group. This may affect the Permissions that the User is granted.';
$_lang['user_group_user_remove'] = 'Remove User from Group';
$_lang['user_group_user_remove_confirm'] = 'Are you sure you want to remove this user from the group?';
$_lang['user_group_user_update_role'] = 'Update Role for User in Usergroup';
$_lang['user_groups'] = 'User Groups';
$_lang['user_gender'] = 'Gender';
$_lang['user_grid_empty'] = 'No users to display';
$_lang['user_grid_paginate'] = 'Displaying users {0} - {1} of {2}';
$_lang['user_is_blocked'] = 'This user is blocked!';
$_lang['user_logincount'] = 'Number of Logins';
$_lang['user_logincount_desc'] = 'The total number of times this User has logged in.';
$_lang['user_male'] = 'Male';
$_lang['user_management_msg'] = 'Here you can choose which user you wish to edit.';
$_lang['user_mobile'] = 'Mobile phone number';
$_lang['user_new'] = 'New User';
$_lang['user_password_changed'] = 'Password successfully changed to: [[+password]]';
$_lang['user_phone'] = 'Phone number';
$_lang['user_photo'] = 'User Photo';
$_lang['user_photo_message'] = 'Enter the image url for the this user or use the insert button to selected or upload an image file on the server.';
$_lang['user_prevlogin'] = 'Last Login';
$_lang['user_prevlogin_desc'] = 'The time that the user last successfully logged in.';
$_lang['user_profile_err_nf'] = 'FATAL ERROR: User profile not found.';
$_lang['user_profile_err_save'] = 'An error occurred while attempting to save the user attributes.';
$_lang['user_remove'] = 'Delete User';
$_lang['user_remove_confirm'] = 'Are you sure you want to delete this user? This is irreversible!';
$_lang['user_remove_multiple'] = 'Delete Multiple Users';
$_lang['user_remove_multiple_confirm'] = 'Are you sure you want to delete these users? This is irreversible!';
$_lang['user_remote_data_msg'] = 'Edit remote user data here.';
$_lang['user_role_update'] = 'Update User Role';
$_lang['user_setting_err_remove'] = 'An error occurred while removing user settings.';
$_lang['user_setting_err_save'] = 'An error occurred while saving user settings.';
$_lang['user_settings'] = 'User Settings';
$_lang['user_settings_desc'] = 'Here you can change specific settings for the user.';
$_lang['user_state'] = 'State';
$_lang['user_sudo'] = 'Sudo User';
$_lang['user_sudo_desc'] = 'If checked, this user will have full access to all the site and will bypass any Access Permissions checks. *DO NOT* check this unless you mean to do so!';
$_lang['user_title'] = 'Create/Edit user';
$_lang['user_update'] = 'Update User';
$_lang['user_updated_password_message'] = 'The User has been updated. The password is: [[+password]]';
$_lang['user_upload_message'] = ' If you wish to stop this user uploading any filetypes in this category, make sure that the \'Use Main Configuration Setting\' checkbox is not ticked and leave the field blank.';
$_lang['user_use_config'] = 'Use System Configuration Setting';
$_lang['user_username_desc'] = 'The unique identifier of this User, and the name by which they will login to the site.';
$_lang['user_website'] = 'Website';
$_lang['user_zip'] = 'Zip';
$_lang['username'] = 'Username';
$_lang['users'] = 'Users';

==> modx-2.3.3-pl-ja.zip: modx-2.3.3-pl-ja/core/lexicon/en/user.inc.php <==
<?php
/**
 * User English lexicon topic
 *
 * @language en
 * @package modx
 * @subpackage lexicon
 */
$_lang['active'] = 'Active';
$_lang['address'] = 'Address';
$_lang['administrator'] = 'Administrator';
$_lang['authority'] = 'Authority';
$_lang['change_password'] = 'Change Password';
$_lang['change_password_confirm'] = 'Confirm password';
$_lang['change_password_new'] = 'New password';
$_lang['city'] = 'City';
$_lang['extended_fields'] = 'Extended Fields';
$_lang['extended_fields_msg'] = 'Edit any extended fields that are implemented here.';
$_lang['login_options'] = 'Login Options';
$_lang['minimum_role'] = 'Minimum Role';
$_lang['password'] = 'Password';
$_lang['password_confirm'] = 'Confirm Password';
$_lang['password_gen_gen'] = 'Let MODX generate a password.';
$_lang['password_gen_method'] = 'New password method';
$_lang['password_gen_specify'] = 'Let me specify the password:';
$_lang['password_method'] = 'Password notification method';
$_lang['password_method_email'] = 'Send the new password by email.';
$_lang['password_method_screen'] = 'Show the new password on screen.';
$_lang['password_new'] = 'New Password';
$_lang['password_notification'] = 'Password Notification';
$_lang['password_old'] = 'Old Password';
$_lang['primary_group'] = 'Primary Group';
$_lang['profile_recent_resources'] = 'Recent Resources';
$_lang['profile_recent_resources_desc'] = 'This is a list of your most recently edited Resources.';
$_lang['remote_data'] = 'Remote Data';
$_lang['role'] = 'Role';
$_lang['role_create'] = 'Create Role';
$_lang['role_desc_authority'] = 'The Authority level of the role. Lower Authority levels are stronger, and inherit the Permissions of Roles with higher authorities in the groups they are assigned to.';
$_lang['role_desc_name'] = 'A name for the Role, such as Content Editor, Publisher, System Administrator, etc.';
$_lang['role_desc_description'] = 'A short description of the Role.';
$_lang['role_err_ae'] = 'A role already exists with that name.';
$_lang['role_err_duplicate'] = 'An error occurred while duplicating the role.';
$_lang['role_err_has_users'] = 'There are users with this role. It cannot be deleted.';
$_lang['role_err_nf'] = 'Role not found.';
$_lang['role_err_nfs'] = 'Role not found with id: [[+role]]';
$_lang['role_err_ns'] = 'Role not specified!';
$_lang['role_err_ns_name'] = 'Please specify a name for the role.';
$_lang['role_err_remove'] = 'An error occurred while trying to remove the role.';
$_lang['role_err_remove_admin'] = 'The role you are trying to delete is the admin role. This role cannot be deleted!';
$_lang['role_remove'] = 'Delete Role';
$_lang['role_remove_confirm'] = 'Are you sure you want to delete this role?';
$_lang['roles'] = 'Roles';
$_lang['rrg_drag'] = 'Drag resources into resource groups here.';
$_lang['ugc_mutate'] = 'User Group Access to Context';
$_lang['ugc_grid_title'] = 'User Group Access to Contexts';
$_lang['ugc_remove'] = 'Remove User Group Access to this Context';
$_lang['ugrg_grid_title'] = 'User Group Access to Resource Groups';
$_lang['ugrg_mutate'] = 'User Group Access to Resource Group';
$_lang['ugrg_remove'] = 'Remove User Group Access to this Resource Group';
$_lang['user'] = 'User';
$_lang['user_active_desc'] = 'Whether or not this User is active. If a User is not active, they will not be able to login to any Context or the manager.';
$_lang['user_add_group'] = 'Add User Group to User';
$_lang['user_already_in_use'] = 'User name is already in use!';
$_lang['user_block'] = 'Blocked';
$_lang['user_block_desc'] = 'If checked, this user will be permanently blocked from logging in.';
$_lang['user_blockedafter'] = 'Blocked After';
$_lang['user_blockedafter_desc'] = 'If set, the user will be blocked after this time occurs.';
$_lang['user_blockeduntil'] = 'Blocked Until';
$_lang['user_blockeduntil_desc'] = 'If set, the user will be blocked until this time.';
$_lang['user_changeddata'] = 'Your data has been changed. Please log in again.';
$_lang['user_class_key_desc'] = 'The MODX Class Key for this user. Do not change this unless you know what you are doing.';
$_lang['user_created_password_message'] = 'The User has been created. The password is: [[+password]]';
$_lang['user_confirm_remove'] = 'Are you sure you want to permanently remove this user?';
$_lang['user_country'] = 'Country';
$_lang['user_dob'] = 'Date of birth';
$_lang['user_doesnt_exist'] = 'User does not exist';
$_lang['user_duplicate'] = 'Duplicate User';
$_lang['user_edit_self_msg'] = 'You may need to log out and log in again after saving to fully update your information.</strong><br>Also, should you choose to generate a new password for yourself, it will be sent to you through email.';
$_lang['user_email'] = 'Email address';
$_lang['user_err_access_permissions_save'] = 'An error occurred while saving user access permissions.';
$_lang['user_err_ae_group'] = 'User is already in that group!';
$_lang['user_err_already_exists'] = 'User name is already in use!';
$_lang['user_err_already_exists_email'] = 'Email already in use!';
$_lang['user_err_cannot_delete_last_admin'] = 'You cannot remove the last User in the Administrator group, as this will prevent administration of your site.';
$_lang['user_err_cannot_delete_self'] = 'You cannot delete yourself!';
$_lang['user_err_nf'] = 'User not found.';
$_lang['user_err_not_specified'] = 'No user specified!';
$_lang['user_err_not_specified_blockedafter'] = 'Please state the blocked after date in mm/dd/yyyy format. ';
$_lang['user_err_not_specified_blockeduntil'] = 'Please state the blocked until date in mm/dd/yyyy format. ';
$_lang['user_err_not_specified_dob'] = 'Please state the birthdate in mm/dd/yyyy format. ';
$_lang['user_err_not_specified_email'] = 'Please specify a valid email address.';
$_lang['user_err_not_specified_fileman_path'] = 'The directory you have specified either:<br />1) Does not exist.<br />2) Does not have read permissions.<br />3) Is not a directory.';
$_lang['user_err_not_specified_manageraccess'] = 'Please specify whether or not the user should have manager access.';
$_lang['user_err_not_specified_managerstartup'] = 'Please specify an existent, valid document ID for the manager login startup page.';
$_lang['user_err_not_specified_managertheme'] = 'The manager theme you have specified has not been uploaded.';
$_lang['user_err_not_specified_mobnumber'] = 'Please specify a valid mobile phone number. (If in US, please specify area code.)';
$_lang['user_err_not_specified_notification_method'] = 'Please specify a notifcation method for the new password.';
$_lang['user_err_not_specified_password'] = 'Please specify a password.';
$_lang['user_err_not_specified_phonenumber'] = 'Please specify a valid phone number. (If in US, please specify area code.)';
$_lang['user_err_not_specified_resourcedir'] = 'The directory you\'ve specified is not a valid directory.';
$_lang['user_err_not_specified_resource_baseurl'] = 'Please specify a valid resource URL.';
$_lang['user_err_not_specified_uploadsize'] = 'Please specify a valid max upload size in bytes.';
$_lang['user_err_not_specified_username'] = 'Please specify a user name.';
$_lang['user_err_ns'] = 'User not specified.';
$_lang['user_err_password'] = 'Incorrect password.';
$_lang['user_err_password_invalid'] = 'Invalid password specified.';
$_lang['user_err_password_invalid_old'] = 'Invalid old password.';
$_lang['user_err_password_too_short'] = 'Password is too short!';
$_lang['user_err_password_no_match'] = 'Passwords do not match.';
$_lang['user_err_remove'] = 'An error occurred while trying to remove the user.';
$_lang['user_err_resource_subdirectory'] = 'The directory you\'ve specified does not contain the %s directories.';
$_lang['user_err_save'] = 'An error occurred while saving the user.';
$_lang['user_err_username_invalid'] = 'Invalid username specified.';
$_lang['user_failedlogincount'] = 'Failed Logins';
$_lang['user_failedlogincount_desc'] = 'The number of times this user has failed to login by entering an incorrect password.';
$_lang['user_fax'] = 'Fax';
$_lang['user_female'] = 'Female';
$_lang['user_full_name'] = 'Full name';
$_lang['user_group'] = 'User Group';
$_lang['user_group_create'] = 'Create User Group';
$_lang['user_group_id'] = 'UG ID';
$_lang['user_group_desc_name'] = 'The name of the User Group';
$_lang['user_group_desc_description'] = 'A short description of the User Group';
$_lang['user_group_desc_parent'] = 'The parent group of this group. Used for organizational purposes.';
$_lang['user_group_desc_dashboard'] = 'The Dashboard that members of this Group (who have this Group as their Primary Group) will use.';
$_lang['user_group_document_group_err_already_exists'] = 'The user group is already attached to that document group.';
$_lang['user_group_document_group_err_create'] = 'An error occurred while trying to attach the user group to the document group.';
$_lang['user_group_document_group_err_not_found'] = 'That user group is not attached to that document group!';
$_lang['user_group_document_group_err_remove'] = 'An error occurred while trying to deattach the user group from the document group.';
$_lang['user_group_err_already_exists'] = 'There is already a user group with that name.';
$_lang['user_group_err_create'] = 'An error occurred while trying to create the user group.';
$_lang['user_group_err_nf'] = 'User group not found!';
$_lang['user_group_err_not_found'] = 'User group not found!';
$_lang['user_group_err_not_specified'] = 'No user group specified!';
$_lang['user_group_err_ns'] = 'User group not specified!';
$_lang['user_group_err_ns_name'] = 'Please specify a name for this user group.';
$_lang['user_group_err_remove'] = 'An error occurred while trying to remove the user group.';
$_lang['user_group_err_remove_admin'] = 'You cannot remove the Administrator group.';
$_lang['user_group_err_save'] = 'An error occurred while trying to save the user group.';
$_lang['user_group_management_msg'] = 'Manage user memberships in groups and apply roles.';
$_lang['user_group_member_err_already_in'] = 'User is already in this user group!';
$_lang['user_group_member_err_create'] = 'An error occurred while attempting to add the user to a user group.';
$_lang['user_group_member_err_nf'] = 'User is not in this user group!';
$_lang['user_group_member_err_remove'] = 'An error occurred while trying to remove the user from the group.';
$_lang['user_group_member_err_save'] = 'An error occurred while trying to add the user to the group.';
$_lang['user_group_new'] = 'New User Group';
$_lang['user_group_parent'] = 'Parent Group';
$_lang['user_group_remove'] = 'Delete User Group';
$_lang['user_group_remove_confirm'] = 'Are you sure you want to delete this User Group?';
$_lang['user_group_settings'] = 'User Group Settings';
$_lang['user_group_settings_desc'] = 'Manage Settings for the User Group';
$_lang['user_group_untitled'] = 'Untitled User Group';
$_lang['user_group_update'] = 'Update User Group';
$_lang['user_group_user_add'] = 'Add User to Group';
$_lang['user_group_user_add_user_desc'] = 'The username of the User to add to the User Group';
$_lang['user_group_user_add_role_desc'] = 'The Role that the User should have in the Group. This may affect the Permissions that the User is granted.';
$_lang['user_group_user_remove'] = 'Remove User from Group';
$_lang['user_group_user_remove_confirm'] = 'Are you sure you want to remove this user from the group?';
$_lang['user_group_user_update_role'] = 'Update Role for User in Usergroup';
$_lang['user_groups'] = 'User Groups';
$_lang['user_gender'] = 'Gender';
$_lang['user_grid_empty'] = 'No users to display';
$_lang['user_grid_paginate'] = 'Displaying users {0} - {1} of {2}';
$_lang['user_is_blocked'] = 'This user is blocked!';
$_lang['user_logincount'] = 'Number of Logins';
$_lang['user_logincount_desc'] = 'The total number of times this User has logged in.';
$_lang['user_male'] = 'Male';
$_lang['user_management_msg'] = 'Here you can choose which user you wish to edit.';
$_lang['user_mobile'] = 'Mobile phone number';
$_lang['user_new'] = 'New User';
$_lang['user_password_changed'] = 'Password successfully changed to: [[+password]]';
$_lang['user_phone'] = 'Phone number';
$_lang['user_photo'] = 'User Photo';
$_lang['user_photo_message'] = 'Enter the image URL for this user or use the insert button to select or upload an image file on the server.';
$_lang['user_prevlogin'] = 'Last Login';
$_lang['user_prevlogin_desc'] = 'The last time that the user successfully logged in.';
$_lang['user_profile_err_nf'] = 'FATAL ERROR: User profile not found.';
$_lang['user_profile_err_save'] = 'An error occurred while attempting to save the user attributes.';
$_lang['user_remove'] = 'Delete User';
$_lang['user_remove_confirm'] = 'Are you sure you want to delete this user? This is irreversible!';
$_lang['user_remove_multiple'] = 'Delete Multiple Users';
$_lang['user_remove_multiple_confirm'] = 'Are you sure you want to delete these users? This is irreversible!';
$_lang['user_remote_data_msg'] = 'Edit remote user data here.';
$_lang['user_role_update'] = 'Update User Role';
$_lang['user_setting_err_remove'] = 'An error occurred while removing user settings.';
$_lang['user_setting_err_save'] = 'An error occurred while saving user settings.';
$_lang['user_settings'] = 'User Settings';
$_lang['user_settings_desc'] = 'Here you can change specific settings for the user.';
$_lang['user_state'] = 'State';
$_lang['user_sudo'] = 'Sudo User';
$_lang['user_sudo_desc'] = 'If checked, this user will have full access to all the site and will bypass any Access Permissions checks. *DO NOT* check this unless you mean to do so!';
$_lang['user_title'] = 'Create/Edit user';
$_lang['user_other'] = 'Other';
$_lang['user_update'] = 'Update User';
$_lang['user_updated_password_message'] = 'The User has been updated. The password is: [[+password]]';
$_lang['user_upload_message'] = 'If you wish to stop this user uploading any filetypes in this category, make sure that the \'Use Main Configuration Setting\' checkbox is not ticked and leave the field blank.';
$_lang['user_use_config'] = 'Use System Configuration Setting';
$_lang['user_username_desc'] = 'The unique identifier of this User, and the name by which they will login to the site.';
$_lang['user_website'] = 'Website';
$_lang['user_zip'] = 'Zip';
$_lang['username'] = 'Username';
$_lang['users'] = 'Users';
